@@ -453,7 +453,7 @@ mod tests {
         invoke_context
             .push(
                 &preparation.message,
-                &preparation.message.instructions[0],
+                &preparation.message.instructions()[0],
                 &program_indices,
                 &preparation.account_indices,
             )
